@@ -60,12 +60,12 @@ class Notifications:
             cron_string = pretty_cron.prettify_cron(current_value)
             content = f"Your {file_path} who run {cron_string} is {status}, check the Logs on your manager below :"
 
-        status_url = f"{encode_proxy_url('assets')}/{status}.png"
+        status_url = f"{encode_proxy_url(t_asset)}/naas_{status}.png"
         message_bytes = file_path.encode("ascii")
         base64_bytes = base64.b64encode(message_bytes)
         file_path_base64 = base64_bytes.decode("ascii")
-        link_url = f"{encode_proxy_url('manager')}/?filter={file_path_base64}"
-        logo_url = f"{encode_proxy_url('manager')}/asset/naas_logo"
+        link_url = f"{encode_proxy_url()}/?filter={file_path_base64}"
+        logo_url = f"{encode_proxy_url(t_asset)}/naas_logo.png"
         try:
             data = {
                 "title": "Naas manager notification",
@@ -73,10 +73,11 @@ class Notifications:
                 "email": email,
                 "content": content,
                 "custom_vars": {
-                    "URL_HOME": encode_proxy_url("manager"),
+                    "URL_HOME": encode_proxy_url(),
                     "URL_LOGO": logo_url,
                     "ALT_LOGO": "Naas Manager LOGO",
                     "URL_IMAGE": status_url,
+                    "ALT_IMAGE": status,
                     "URL_LINK": link_url,
                 },
             }
